import click


@click.group()
def cli():
    pass


@cli.command()
@click.option("--port", prompt="Port", help="Port", default=5000)
@click.option("--debug", prompt="Debug", help="Debug", default=False)
def runprocessor(port: int, debug: bool):
    from greble_flow.web.managment import app

    app.run(port=port, debug=debug)



from flask import Flask, jsonify, request, abort

from greble_flow.managment.manager import FlowManager

app = Flask(__name__)
flow_manager = FlowManager()


@app.route("/flow-processor/<flow_name>/", methods=['POST'])
def run_flow(flow_name):
    # flow_manager
    if not request.json:
        abort(400)

    return jsonify({
        "result": flow_manager.run(flow_name, request.json)
    })



from greble_flow.processors.base import BaseFlowProcessor


class SimpleProcessor(BaseFlowProcessor):
    name = "simple-flow-processor"

    def execute(self, *args, **kwargs):
        return {
            "test": 1
        }
